@@ -13,6 +13,10 @@ from hyperbrowser.models import (
     TypeTextActionParams,
     Coordinate,
     HoldKeyActionParams,
+    MouseDownActionParams,
+    MouseUpActionParams,
+    ComputerActionMouseButton,
+    GetClipboardTextActionParams,
 )
 
 
@@ -45,7 +49,7 @@ class ComputerActionManager:
         session: Union[SessionDetail, str],
         x: Optional[int] = None,
         y: Optional[int] = None,
-        button: str = "left",
+        button: ComputerActionMouseButton = "left",
         num_clicks: int = 1,
         return_screenshot: bool = False,
     ) -> ComputerActionResponse:
@@ -95,6 +99,26 @@ class ComputerActionManager:
         )
         return self._execute_request(session, params)
 
+    def mouse_down(
+        self,
+        session: Union[SessionDetail, str],
+        button: ComputerActionMouseButton = "left",
+        return_screenshot: bool = False,
+    ) -> ComputerActionResponse:
+        params = MouseDownActionParams(
+            button=button, return_screenshot=return_screenshot
+        )
+        return self._execute_request(session, params)
+
+    def mouse_up(
+        self,
+        session: Union[SessionDetail, str],
+        button: ComputerActionMouseButton = "left",
+        return_screenshot: bool = False,
+    ) -> ComputerActionResponse:
+        params = MouseUpActionParams(button=button, return_screenshot=return_screenshot)
+        return self._execute_request(session, params)
+
     def drag(
         self,
         session: Union[SessionDetail, str],
@@ -131,3 +155,11 @@ class ComputerActionManager:
             return_screenshot=return_screenshot,
         )
         return self._execute_request(session, params)
+
+    def get_clipboard_text(
+        self,
+        session: Union[SessionDetail, str],
+        return_screenshot: bool = False,
+    ) -> ComputerActionResponse:
+        params = GetClipboardTextActionParams(return_screenshot=return_screenshot)
+        return self._execute_request(session, params)
