@@ -5,6 +5,26 @@ from .agents.browser_use import (
     StartBrowserUseTaskParams,
     StartBrowserUseTaskResponse,
     BrowserUseApiKeys,
+    BrowserUseAgentBrain,
+    BrowserUseAgentOutput,
+    BrowserUseActionResult,
+    BrowserUseStepMetadata,
+    BrowserUseTabInfo,
+    BrowserUseCoordinates,
+    BrowserUseCoordinateSet,
+    BrowserUseViewportInfo,
+    BrowserUseDOMHistoryElement,
+    BrowserUseBrowserStateHistory,
+    BrowserUseAgentHistory,
+    BrowserUseAgentOutputV0710,
+    BrowserUseActionResultV0710,
+    BrowserUseBrowserStateHistoryV0710,
+    BrowserUseStepMetadataV0710,
+    BrowserUseAgentHistoryV0710,
+    BrowserUseAgentHistoryLatest,
+    BrowserUseTaskMetadata,
+    BrowserUseStep,
+    cast_steps_for_version,
 )
 from .agents.claude_computer_use import (
     ClaudeComputerUseTaskStatus,
@@ -64,6 +84,7 @@ from .consts import (
     SessionEventLogType,
     State,
     SessionRegion,
+    BrowserUseVersion,
 )
 from .crawl import (
     CrawledPage,
@@ -82,6 +103,7 @@ from .extract import (
     ExtractJobStatusResponse,
     StartExtractJobParams,
     StartExtractJobResponse,
+    ExtractJobMetadata,
 )
 from .profile import (
     CreateProfileParams,
@@ -105,6 +127,7 @@ from .scrape import (
     StartBatchScrapeJobResponse,
     StartScrapeJobParams,
     StartScrapeJobResponse,
+    StorageStateOptions,
 )
 from .computer_action import (
     ClickActionParams,
@@ -114,11 +137,17 @@ from .computer_action import (
     Coordinate,
     DragActionParams,
     HoldKeyActionParams,
+    MouseDownActionParams,
+    MouseUpActionParams,
     MoveMouseActionParams,
     PressKeysActionParams,
     ScreenshotActionParams,
     ScrollActionParams,
     TypeTextActionParams,
+    ComputerActionMouseButton,
+    GetClipboardTextActionParams,
+    ComputerActionResponseDataClipboardText,
+    ComputerActionResponseData,
 )
 from .session import (
     BasicResponse,
@@ -163,6 +192,7 @@ __all__ = [
     "SessionEventLogType",
     "State",
     "SessionRegion",
+    "BrowserUseVersion",
     # agents
     "HyperAgentTaskStatus",
     "HyperAgentActionOutput",
@@ -179,6 +209,26 @@ __all__ = [
     "BrowserUseTaskStatusResponse",
     "StartBrowserUseTaskParams",
     "StartBrowserUseTaskResponse",
+    "BrowserUseAgentBrain",
+    "BrowserUseAgentOutput",
+    "BrowserUseActionResult",
+    "BrowserUseStepMetadata",
+    "BrowserUseTabInfo",
+    "BrowserUseCoordinates",
+    "BrowserUseCoordinateSet",
+    "BrowserUseViewportInfo",
+    "BrowserUseDOMHistoryElement",
+    "BrowserUseBrowserStateHistory",
+    "BrowserUseAgentHistory",
+    "BrowserUseAgentOutputV0710",
+    "BrowserUseActionResultV0710",
+    "BrowserUseBrowserStateHistoryV0710",
+    "BrowserUseStepMetadataV0710",
+    "BrowserUseAgentHistoryV0710",
+    "BrowserUseAgentHistoryLatest",
+    "BrowserUseStep",
+    "BrowserUseTaskMetadata",
+    "cast_steps_for_version",
     "ClaudeComputerUseTaskStatus",
     "ClaudeComputerUseStepResponse",
     "ClaudeComputerUseTaskData",
@@ -222,6 +272,7 @@ __all__ = [
     "ExtractJobStatusResponse",
     "StartExtractJobParams",
     "StartExtractJobResponse",
+    "ExtractJobMetadata",
     # profile
     "CreateProfileParams",
     "CreateProfileResponse",
@@ -243,6 +294,7 @@ __all__ = [
     "StartBatchScrapeJobResponse",
     "StartScrapeJobParams",
     "StartScrapeJobResponse",
+    "StorageStateOptions",
     # session
     "BasicResponse",
     "CreateSessionParams",
@@ -274,9 +326,15 @@ __all__ = [
     "Coordinate",
     "DragActionParams",
     "HoldKeyActionParams",
+    "MouseDownActionParams",
+    "MouseUpActionParams",
     "MoveMouseActionParams",
     "PressKeysActionParams",
     "ScreenshotActionParams",
     "ScrollActionParams",
     "TypeTextActionParams",
+    "ComputerActionMouseButton",
+    "GetClipboardTextActionParams",
+    "ComputerActionResponseDataClipboardText",
+    "ComputerActionResponseData",
 ]
