@@ -8,12 +8,20 @@ class ComputerAction(str, Enum):
 
     CLICK = "click"
     DRAG = "drag"
-    PRESS_KEYS = "press_keys"
     HOLD_KEY = "hold_key"
+    MOUSE_DOWN = "mouse_down"
+    MOUSE_UP = "mouse_up"
     MOVE_MOUSE = "move_mouse"
+    PRESS_KEYS = "press_keys"
     SCREENSHOT = "screenshot"
     SCROLL = "scroll"
     TYPE_TEXT = "type_text"
+    GET_CLIPBOARD_TEXT = "get_clipboard_text"
+
+
+ComputerActionMouseButton = Literal[
+    "left", "right", "middle", "back", "forward", "wheel"
+]
 
 
 class Coordinate(BaseModel):
@@ -31,9 +39,7 @@ class ClickActionParams(BaseModel):
     action: Literal[ComputerAction.CLICK] = ComputerAction.CLICK
     x: Optional[int] = Field(default=None)
     y: Optional[int] = Field(default=None)
-    button: Literal["left", "right", "middle", "back", "forward", "wheel"] = Field(
-        default="left"
-    )
+    button: ComputerActionMouseButton = Field(default="left")
     num_clicks: int = Field(serialization_alias="numClicks", default=1)
     return_screenshot: bool = Field(
         serialization_alias="returnScreenshot", default=False
@@ -77,6 +83,30 @@ class HoldKeyActionParams(BaseModel):
     )
 
 
+class MouseDownActionParams(BaseModel):
+    """Parameters for mouse down action."""
+
+    model_config = ConfigDict(use_enum_values=True)
+
+    action: Literal[ComputerAction.MOUSE_DOWN] = ComputerAction.MOUSE_DOWN
+    button: ComputerActionMouseButton = Field(default="left")
+    return_screenshot: bool = Field(
+        serialization_alias="returnScreenshot", default=False
+    )
+
+
+class MouseUpActionParams(BaseModel):
+    """Parameters for mouse up action."""
+
+    model_config = ConfigDict(use_enum_values=True)
+
+    action: Literal[ComputerAction.MOUSE_UP] = ComputerAction.MOUSE_UP
+    button: ComputerActionMouseButton = Field(default="left")
+    return_screenshot: bool = Field(
+        serialization_alias="returnScreenshot", default=False
+    )
+
+
 class MoveMouseActionParams(BaseModel):
     """Parameters for move mouse action."""
 
@@ -125,6 +155,19 @@ class TypeTextActionParams(BaseModel):
     )
 
 
+class GetClipboardTextActionParams(BaseModel):
+    """Parameters for get clipboard text action."""
+
+    model_config = ConfigDict(use_enum_values=True)
+
+    action: Literal[ComputerAction.GET_CLIPBOARD_TEXT] = (
+        ComputerAction.GET_CLIPBOARD_TEXT
+    )
+    return_screenshot: bool = Field(
+        serialization_alias="returnScreenshot", default=False
+    )
+
+
 ComputerActionParams = Union[
     ClickActionParams,
     DragActionParams,
@@ -133,9 +176,24 @@ ComputerActionParams = Union[
     ScreenshotActionParams,
     ScrollActionParams,
     TypeTextActionParams,
+    HoldKeyActionParams,
+    MouseDownActionParams,
+    MouseUpActionParams,
+    GetClipboardTextActionParams,
 ]
 
 
+class ComputerActionResponseDataClipboardText(BaseModel):
+    """Data for get clipboard text action."""
+
+    model_config = ConfigDict(populate_by_alias=True)
+
+    clipboard_text: Optional[str] = Field(default=None, alias="clipboardText")
+
+
+ComputerActionResponseData = Union[ComputerActionResponseDataClipboardText]
+
+
 class ComputerActionResponse(BaseModel):
     """Response from computer action API."""
 
@@ -145,5 +203,6 @@ class ComputerActionResponse(BaseModel):
 
     success: bool
     screenshot: Optional[str] = None
+    data: Optional[ComputerActionResponseData] = None
     error: Optional[str] = None
     message: Optional[str] = None
